==> neo4j-cypher-compiler-2.2_2.11-2.2.2-sources.jar: org/neo4j/cypher/internal/compiler/v2_2/planner/logical/planExpressionRewriter.scala <==
/*
 * Copyright (c) 2002-2015 "Neo Technology,"
 * Network Engine for Objects in Lund AB [http://neotechnology.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.cypher.internal.compiler.v2_2.planner.logical

import org.neo4j.cypher.internal.compiler.v2_2.ast.{NestedPlanExpression, PatternExpression, Expression}
import org.neo4j.cypher.internal.compiler.v2_2.{bottomUp, IdentityMap, Rewriter}
import org.neo4j.cypher.internal.compiler.v2_2.planner.logical.plans.{IdName, LogicalPlan}

case class planExpressionRewriter(rewriterFactory: (Set[IdName], Expression, LogicalPlanningContext) => Rewriter) extends (LogicalPlanningContext => Rewriter) {

  def apply(context: LogicalPlanningContext): Rewriter = Rewriter.lift {
    case plan: LogicalPlan =>
      plan.mapExpressions {
        case (arguments, expression) =>
          val rewriter = rewriterFactory(arguments, expression, context)
          expression.endoRewrite(rewriter)
      }
  }
}

==> neo4j-cypher-compiler-2.3-2.3.1-sources.jar: org/neo4j/cypher/internal/compiler/v2_3/planner/logical/planExpressionRewriter.scala <==
/*
 * Copyright (c) 2002-2015 "Neo Technology,"
 * Network Engine for Objects in Lund AB [http://neotechnology.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.cypher.internal.compiler.v2_3.planner.logical

import org.neo4j.cypher.internal.frontend.v2_3.ast.Expression
import org.neo4j.cypher.internal.compiler.v2_3.planner.logical.plans.{IdName, LogicalPlan}
import org.neo4j.cypher.internal.frontend.v2_3.Rewriter

case class planExpressionRewriter(rewriterFactory: (Set[IdName], Expression, LogicalPlanningContext) => Rewriter) extends (LogicalPlanningContext => Rewriter) {

  def apply(context: LogicalPlanningContext): Rewriter = Rewriter.lift {
    case plan: LogicalPlan =>
      plan.mapExpressions {
        case (arguments, expression) =>
          val rewriter = rewriterFactory(arguments, expression, context)
          expression.endoRewrite(rewriter)
      }
  }
}
